Ape-pie client
==============

.. pull-quote:: Monkey see, monkey GET.

|build-status| |code-quality| |black| |coverage| |docs|

|python-versions| |pypi-version|

Ape-pie is a small API client abstraction layer on top of requests_.

.. contents::

.. section-numbering::

Features
========

* No leaky abstraction - use the familiar ``requests`` Python interfaces.
* Modular configuration adapters for your project's domain(s).
* Highly customizable for your needs.

Installation and usage
======================

Quickstart and API reference documentation are hosted on ReadTheDocs_.


.. |build-status| image:: https://github.com/maykinmedia/ape-pie/workflows/Tests%20and%20PyPI%20publishing/badge.svg
    :alt: Build status
    :target: https://github.com/maykinmedia/ape-pie/actions?query=workflow%3A%22Tests+and+PyPI+publishing%22

.. |code-quality| image:: https://github.com/maykinmedia/ape-pie/workflows/Linting%20and%20code%20quality/badge.svg
     :alt: Code quality checks
     :target: https://github.com/maykinmedia/ape-pie/actions?query=workflow%3A%22Linting+and+code+quality%22

.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black

.. |coverage| image:: https://codecov.io/gh/maykinmedia/ape-pie/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/maykinmedia/ape-pie
    :alt: Coverage status

.. |docs| image:: https://readthedocs.org/projects/ape-pie/badge/?version=latest
    :target: https://ape-pie.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. |python-versions| image:: https://img.shields.io/pypi/pyversions/ape-pie.svg

.. |pypi-version| image:: https://img.shields.io/pypi/v/ape-pie.svg
    :target: https://pypi.org/project/ape-pie/

.. _requests: https://docs.python-requests.org/en/latest/index.html
.. _ReadTheDocs: https://ape-pie.readthedocs.io/en/latest/
